@@ -12,7 +12,7 @@ __author__ = 'Jens Finkhaeuser'
 __copyright__ = 'Copyright (c) 2016-2020 Jens Finkhaeuser'
 __license__ = 'MIT +no-false-attribs'
 __all__ = ('util', 'mixins', 'cli', 'convert')
-__version__ = '0.19.0'
+__version__ = '0.20.0'
 
 
 # Define our own error class
@@ -282,7 +282,7 @@ class ResolvingParser(BaseParser):
     # We therefore use our own resolver first, and validate later.
     from .util.resolver import RefResolver
     forward_arg_names = ('encoding', 'recursion_limit',
-            'recursion_limit_handler', 'resolve_types')
+            'recursion_limit_handler', 'resolve_types', 'resolve_method')
     forward_args = {
       k: v for (k, v) in self.options.items() if k in forward_arg_names
     }
